<?php
/*
* 2007-2015 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author PrestaShop SA <contact@prestashop.com>
*  @copyright  2007-2015 PrestaShop SA
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

use PrestaShop\PrestaShop\Core\Payment\PaymentOption;

if (!defined('_PS_VERSION_')) {
    exit;
}

class TrustPay extends PaymentModule
{
    protected $_html = '';
    protected $_postErrors = array();

    public $details;
    public $owner;
    public $address;
    public $extra_mail_vars;

    public function __construct()
    {
        $this->name = 'trustpay';
        $this->tab = 'payments_gateways';
        $this->version = '1.0.0';
        $this->ps_versions_compliancy = array('min' => '1.7', 'max' => _PS_VERSION_);
        $this->author = 'Ghana Dot Com';
        $this->controllers = array('payment', 'validation');
        $this->is_eu_compatible = 0;

        $this->currencies = true;
        $this->currencies_mode = 'checkbox';

        $config = Configuration::getMultiple(array('TRUSTPAY_SECRETKEY', 'TRUSTPAY_PUBLICKEY'));

        $this->bootstrap = true;
        parent::__construct();

        $this->displayName = $this->l('TrustPay');
        $this->description = $this->l('Pay with mobile money, visa and crypto');
        $this->confirmUninstall = $this->l('Are you sure about removing TrustPay?');

        if (!count(Currency::checkPaymentCurrencies($this->id))) {
            $this->warning = $this->l('No currency has been set for this module.');
        }
    }

    public function install()
    {
        if (!parent::install() || !$this->registerHook('paymentOptions') || !$this->registerHook('paymentReturn')) {
            return false;
        }
        return true;
    }

    public function uninstall()
    {
        if (!Configuration::deleteByName('TRUSTPAY_SECRETKEY') || !Configuration::deleteByName('TRUSTPAY_PUBLICKEY') || !parent::uninstall()) 
        {
            return false;
        }
        return true;
    }

    public function hookPaymentOptions($params)
    {
        if (!$this->active) {
            return;
        }

        if (!$this->checkCurrency($params['cart'])) {
            return;
        }

        $payment_options = [
            $this->getExternalPaymentOption()
        ];

        return $payment_options;
    }

    public function checkCurrency($cart)
    {
        $currency_order = new Currency($cart->id_currency);
        $currencies_module = $this->getCurrency($cart->id_currency);

        if (is_array($currencies_module)) {
            foreach ($currencies_module as $currency_module) {
                if ($currency_order->id == $currency_module['id_currency']) {
                    return true;
                }
            }
        }
        return false;
    }

    public function getExternalPaymentOption()
    {

        $config = $this->getConfigFieldsValues();
        $publicKey = $config['TRUSTPAY_PUBLICKEY'];
        $secretKey = $config['TRUSTPAY_SECRETKEY'];

        $externalOption = new PaymentOption();
        $externalOption->setCallToActionText($this->l('Pay with TrustPay'))
                       ->setAction($this->context->link->getModuleLink($this->name, 'validation', array(), true))
                       ->setInputs([
                            'apiKey' => [
                                'name' => 'apiKey',
                                'type' => 'hidden',
                                'value' => $publicKey,
                            ],
                            'secretKey' => [
                                'name' => 'secretKey',
                                'type' => 'hidden',
                                'value' => $secretKey,
                            ],
                        ])
                       ->setAdditionalInformation($this->context->smarty->fetch('module:trustpay/views/templates/front/payment_infos.tpl'));
                       //->setLogo(Media::getMediaPath(_PS_MODULE_DIR_.$this->name.'/payment.jpg'));

        return $externalOption;
    }

    public function getContent()
    {
        $output = null;

        if (Tools::isSubmit('submit'.$this->name)) {
            $api_key = strval(Tools::getValue('TRUSTPAY_PUBLICKEY'));
            $api_secret = strval(Tools::getValue('TRUSTPAY_SECRETKEY'));

            if ((
                !$api_key ||
                empty($api_key) ||
                !Validate::isGenericName($api_key)
            ) && (
                !$api_secret || 
                empty($api_secret) || 
                !Validate::isGenericName($api_secret)
                )) {
                $output .= $this->displayError($this->l('Invalid Configuration value'));
            } else {
                Configuration::updateValue('TRUSTPAY_PUBLICKEY', $api_key);
                Configuration::updateValue('TRUSTPAY_SECRETKEY', $api_secret);
                $output .= $this->displayConfirmation($this->l('Settings updated'));
            }
        }

        return $output.$this->displayForm();
    }

    public function displayForm()
    {
        // Get default language
        $defaultLang = (int)Configuration::get('PS_LANG_DEFAULT');

        // Init Fields form array
        $fieldsForm[0]['form'] = [
            'legend' => [
                'title' => $this->l('Settings'),
            ],
            'input' => [
                [
                    'type' => 'text',
                    'label' => $this->l('API KEY'),
                    'name' => 'TRUSTPAY_PUBLICKEY',
                    'size' => 35,
                    'required' => true
                ],
                [
                    'type' => 'text',
                    'label' => $this->l('API SECRET'),
                    'name' => 'TRUSTPAY_SECRETKEY',
                    'size' => 35,
                    'required' => true
                ],
            ],
            'submit' => [
                'title' => $this->l('Save'),
                'class' => 'btn btn-default pull-right'
            ]
        ];

        $helper = new HelperForm();

        // Module, token and currentIndex
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;

        // Language
        $helper->default_form_language = $defaultLang;
        $helper->allow_employee_form_lang = $defaultLang;

        // Title and toolbar
        $helper->title = $this->displayName;
        $helper->show_toolbar = true;        // false -> remove toolbar
        $helper->toolbar_scroll = true;      // yes - > Toolbar is always visible on the top of the screen.
        $helper->submit_action = 'submit'.$this->name;
        $helper->toolbar_btn = [
            'save' => [
                'desc' => $this->l('Save'),
                'href' => AdminController::$currentIndex.'&configure='.$this->name.'&save'.$this->name.
                '&token='.Tools::getAdminTokenLite('AdminModules'),
            ],
            'back' => [
                'href' => AdminController::$currentIndex.'&token='.Tools::getAdminTokenLite('AdminModules'),
                'desc' => $this->l('Back to list')
            ]
        ];

        // Load current value
        $helper->fields_value['TRUSTPAY_PUBLICKEY'] = Configuration::get('TRUSTPAY_PUBLICKEY');
        $helper->fields_value['TRUSTPAY_SECRETKEY'] = Configuration::get('TRUSTPAY_SECRETKEY');

        return $helper->generateForm($fieldsForm);
    }

    public function getConfigFieldsValues()
    {
        return array(
            'TRUSTPAY_SECRETKEY' => Tools::getValue('TRUSTPAY_SECRETKEY', Configuration::get('TRUSTPAY_SECRETKEY')),
            'TRUSTPAY_PUBLICKEY' => Tools::getValue('TRUSTPAY_PUBLICKEY', Configuration::get('TRUSTPAY_PUBLICKEY')), 
        );
    }

}
